@@ -33,9 +33,7 @@
 
 #include <KLocalizedString>
 
-#include <qbitmap.h>
-#include <qpainter.h>
-#include <qpixmap.h>
+#include <QPixmap>
 
 
 static int lineWidths [] = {1, 2, 3, 5, 8};
@@ -68,9 +66,7 @@ kpToolWidgetLineWidth::kpToolWidgetLineWidth (QWidget *parent, const QString &na
     finishConstruction (0, 0);
 }
 
-kpToolWidgetLineWidth::~kpToolWidgetLineWidth ()
-{
-}
+kpToolWidgetLineWidth::~kpToolWidgetLineWidth () = default;
 
 int kpToolWidgetLineWidth::lineWidth () const
 {
@@ -81,8 +77,9 @@ int kpToolWidgetLineWidth::lineWidth () const
 bool kpToolWidgetLineWidth::setSelected (int row, int col, bool saveAsDefault)
 {
     const bool ret = kpToolWidgetBase::setSelected (row, col, saveAsDefault);
-    if (ret)
+    if (ret) {
         emit lineWidthChanged (lineWidth ());
+    }
     return ret;
 }
 
